=============
Release Notes
=============

.. toctree::
    :maxdepth: 1

    release_notes_1.23.1
    release_notes_1.23
    release_notes_1.22.1
    release_notes_1.22
    release_notes_1.21.1
    release_notes_1.21
    release_notes_1.20.1
    release_notes_1.20
    release_notes_1.19.1
    release_notes_1.19
    release_notes_1.18.1
    release_notes_1.18
    release_notes_1.17
    release_notes_1.16.2
    release_notes_1.16.1
    release_notes_1.16
    release_notes_1.15.1
    release_notes_1.15
    release_notes_1.14
    release_notes_1.13

For releases before 1.13, see the migration guides:

:doc:`../migrations/migrations`
